/**
 * For Android, ordinary call looks like {webView.loadUrl("javascript:jsFunction(paramsAsJson)")}.
 * According to RFC-(???), size of url is limited, what means that we can't do ordinary call
 * in case, when params len is too big. Some additional info about URL's length can be found there:
 * http://stackoverflow.com/a/417184/195671
 *
 * For handling this trouble, we make a hack:
 * 1. Call special 'proxy' JS function, which gets origin JS function's name and 'paramsId' - id,
 * using which 'proxy' can as origin params from 'native' (Android Java code). Using that way,
 * length of params is not limited.
 * 2. 'Proxy' asks for origin params from 'native', using 'paramsId'
 * 3. 'Proxy' calls origin JS function with origin params using JS's 'apply()' method.
 * 4. Success!
 */
function proxiedJsCall(jsFunction, requestId) {
    var paramsJson = window.mail.getProxiedJsParams(requestId);
    var params = JSON.parse(paramsJson);
    jsFunction.apply(this, params);
}